@@ -58,16 +58,16 @@ int amber_qc(amdlibWAVELENGTH *imdWave, amdlibVIS *imdVis, amdlibVIS2 *imdVis2,
 	double QC_LAMBDA_BIN3_MAX=0.;
 	int    QC_LAMBDA_BIN3_CHAN=0;
 
-	int cen_mean=0;
+	//int cen_mean=0;
 	int cen_min=0;
 	int cen_max=0;
-	int bin1_mean=0;
+	//int bin1_mean=0;
 	int bin1_min=0;
 	int bin1_max=0;
-	int bin2_mean=0;
+	//int bin2_mean=0;
 	int bin2_min=0;
 	int bin2_max=0;
-	int bin3_mean=0;
+	//int bin3_mean=0;
 	int bin3_min=0;
 	int bin3_max=0;
 
@@ -84,27 +84,27 @@ int amber_qc(amdlibWAVELENGTH *imdWave, amdlibVIS *imdVis, amdlibVIS2 *imdVis2,
 	 *  full wavelength covered by the observation */
 
 
-	cen_mean=(int)(imdVis2->nbWlen/2.);
+	//cen_mean=(int)(imdVis2->nbWlen/2.);
 	cen_min =(int)((imdVis2->nbWlen/2.)-(imdVis2->nbWlen*USE_CEN/2.));
 	cen_max =(int)((imdVis2->nbWlen/2.)+(imdVis2->nbWlen*USE_CEN/2.));
 	if (cen_min<0) cen_min=0;
 	if (cen_max>(imdVis2->nbWlen-1)) cen_max=(imdVis2->nbWlen-1);
 
-	bin1_mean= (int)(imdVis2->nbWlen*(1./6.));
+	//bin1_mean= (int)(imdVis2->nbWlen*(1./6.));
 	bin1_min =(int)((imdVis2->nbWlen*(1./6.))-(imdVis2->nbWlen*USE_BIN1/2.));
 	bin1_max =(int)((imdVis2->nbWlen*(1./6.))+(imdVis2->nbWlen*USE_BIN1/2.));
 	if (bin1_min<0) bin1_min=0;
 	if (bin1_max>(imdVis2->nbWlen-1)) bin1_max=(imdVis2->nbWlen-1);
 
 
-	bin2_mean= (int)(imdVis2->nbWlen*(3./6.));
+	//bin2_mean= (int)(imdVis2->nbWlen*(3./6.));
 	bin2_min =(int)((imdVis2->nbWlen*(3./6.))-(imdVis2->nbWlen*USE_BIN2/2.));
 	bin2_max =(int)((imdVis2->nbWlen*(3./6.))+(imdVis2->nbWlen*USE_BIN2/2.));
 	if (bin2_min<0) bin2_min=0;
 	if (bin2_max>(imdVis2->nbWlen-1)) bin2_max=(imdVis2->nbWlen-1);
 
 
-	bin3_mean= (int)(imdVis2->nbWlen*(5./6.));
+	//bin3_mean= (int)(imdVis2->nbWlen*(5./6.));
 	bin3_min =(int)((imdVis2->nbWlen*(5./6.))-(imdVis2->nbWlen*USE_BIN3/2.));
 	bin3_max =(int)((imdVis2->nbWlen*(5./6.))+(imdVis2->nbWlen*USE_BIN3/2.));
 	if (bin3_min<0) bin3_min=0;
