@@ -379,7 +379,7 @@ amdmsCOMPL amdmsCompensateEBiasByMap(amdmsCALIBRATION_SETUP *setup, amdmsDATA *c
 
 amdmsCOMPL amdmsCompensateEBiasBySimpleExp1D(amdmsCALIBRATION_SETUP *setup, amdmsDATA *calData)
 {
-  int                     nPixels;
+  //int                     nPixels;
   int                     iPixel;
   int                     iX, iY;
   int                     nDP;
@@ -395,7 +395,7 @@ amdmsCOMPL amdmsCompensateEBiasBySimpleExp1D(amdmsCALIBRATION_SETUP *setup, amdm
     amdmsFatal(__FILE__, __LINE__, "could not create fit for electronic bias!");
     return amdmsFAILURE;
   }
-  nPixels = calData->nx*calData->ny;
+  //nPixels = calData->nx*calData->ny;
   if (setup->rowOffsets == NULL) {
     setup->rowOffsets = (amdmsPIXEL *)calloc((size_t)setup->detNY, sizeof(amdmsPIXEL));
     if (setup->rowOffsets == NULL) {
@@ -492,7 +492,7 @@ amdmsCOMPL amdmsCompensateEBiasBySimpleExp1D(amdmsCALIBRATION_SETUP *setup, amdm
 
 amdmsCOMPL amdmsCompensateEBiasBySimpleSmooth1D(amdmsCALIBRATION_SETUP *setup, amdmsDATA *calData)
 {
-  int          nPixels;
+  //int          nPixels;
   int          iPixel;
   int          iX, iY;
 
@@ -502,7 +502,7 @@ amdmsCOMPL amdmsCompensateEBiasBySimpleSmooth1D(amdmsCALIBRATION_SETUP *setup, a
   if ((setup->corrFlag & amdmsELECTRONIC_BIAS_CORRECTION) == 0) {
     return amdmsSUCCESS;
   }
-  nPixels = calData->nx*calData->ny;
+  //nPixels = calData->nx*calData->ny;
   if (setup->rowOffsets == NULL) {
     setup->rowOffsets = (amdmsPIXEL *)calloc((size_t)setup->detNY, sizeof(amdmsPIXEL));
     if (setup->rowOffsets == NULL) {
@@ -626,7 +626,7 @@ amdmsCOMPL amdmsCompensateGlobalBias(amdmsCALIBRATION_SETUP *setup, amdmsDATA *c
 
 amdmsCOMPL amdmsCompensateFNoise(amdmsCALIBRATION_SETUP *setup, amdmsDATA *calData)
 {
-  int          nPixels;
+  //int          nPixels;
   int          iPixel;
   int          iX, iY;
   int          iW;
@@ -638,7 +638,7 @@ amdmsCOMPL amdmsCompensateFNoise(amdmsCALIBRATION_SETUP *setup, amdmsDATA *calDa
   if ((setup->corrFlag & amdmsROW_OFFSET_CORRECTION) == 0) {
     return amdmsSUCCESS;
   }
-  nPixels = calData->nx*calData->ny;
+  //nPixels = calData->nx*calData->ny;
   if (setup->rowOffsets == NULL) {
     setup->rowOffsets = (amdmsPIXEL *)calloc((size_t)setup->detNY, sizeof(amdmsPIXEL));
     if (setup->rowOffsets == NULL) {
@@ -754,7 +754,7 @@ amdmsCOMPL amdmsCompensateFlatfield(amdmsCALIBRATION_SETUP *setup, amdmsDATA *ca
 
 amdmsCOMPL amdmsCompensateBadPixel(amdmsCALIBRATION_SETUP *setup, amdmsDATA *calData)
 {
-  int          nPixels;
+  //int          nPixels;
   int          iPixel;
   int          hPixel;
   int          iX, iY;
@@ -767,7 +767,7 @@ amdmsCOMPL amdmsCompensateBadPixel(amdmsCALIBRATION_SETUP *setup, amdmsDATA *cal
   if ((setup->corrFlag & amdmsBAD_PIXEL_CORRECTION) == 0) {
     return amdmsSUCCESS;
   }
-  nPixels = calData->nx*calData->ny;
+  //nPixels = calData->nx*calData->ny;
   for (iY = 0; iY < calData->ny ; iY++) {
     for (iX = 0; iX < calData->nx; iX++) {
       iPixel = calData->nx*iY + iX;
@@ -794,12 +794,12 @@ amdmsCOMPL amdmsCompensateBadPixel(amdmsCALIBRATION_SETUP *setup, amdmsDATA *cal
 
 amdmsCOMPL amdmsCalibrateData(amdmsCALIBRATION_SETUP *setup, amdmsDATA *rawData, amdmsDATA *calData)
 {
-  int          nPixels;
+  //int          nPixels;
 
   if ((setup == NULL) || (rawData == NULL) || (calData == NULL)) {
     return amdmsFAILURE;
   }
-  nPixels = rawData->nx*rawData->ny;
+  //nPixels = rawData->nx*rawData->ny;
   if (amdmsAllocateData(calData, rawData->nx, rawData->ny) != amdmsSUCCESS) {
     return amdmsFAILURE;
   }
@@ -1009,9 +1009,9 @@ amdmsCOMPL amdmsCalcStatBox(amdmsCALIBRATION_SETUP *setup, amdmsDATA *data, int
   int           iLeft, iRight, iBottom, iTop;
   double        m;
   double        v;
-  amdmsPIXEL   *bpm = NULL;
-  amdmsPIXEL   *pemFI = NULL;
-  amdmsPIXEL   *pemLI = NULL;
+  //amdmsPIXEL   *bpm = NULL;
+  //amdmsPIXEL   *pemFI = NULL;
+  //amdmsPIXEL   *pemLI = NULL;
 
   /*
   amdmsDebug(__FILE__, __LINE__, "amdmsCalcStatBox(.., .., %d, %d, %d, %d, %d,, %d, %d, %d, %d .., ..)",
@@ -1032,9 +1032,9 @@ amdmsCOMPL amdmsCalcStatBox(amdmsCALIBRATION_SETUP *setup, amdmsDATA *data, int
 
   m = 0.0;
   goodPixels = 0;
-  bpm = setup->bpmData.data;
-  pemFI = setup->pemDataFI.data;
-  pemLI = setup->pemDataLI.data;
+  //bpm = setup->bpmData.data;
+  //pemFI = setup->pemDataFI.data;
+  //pemLI = setup->pemDataLI.data;
   for (iX = oLeft; iX <= oRight; iX++) {
     for (iY = oBottom; iY <= oTop; iY++) {
       if ((iX >= iLeft) && (iX <= iRight) && (iY >= iBottom) && (iY <= iTop)) continue;
@@ -1068,7 +1068,7 @@ amdmsCOMPL amdmsCalcStatBox(amdmsCALIBRATION_SETUP *setup, amdmsDATA *data, int
 
 amdmsCOMPL amdmsSmoothData(amdmsCALIBRATION_SETUP *calib, amdmsDATA *src, amdmsDATA *dst)
 {
-  int          nPixels;
+  //int          nPixels;
   int          iPixel;
   int          hPixel;
   int          iX, iY;
@@ -1082,7 +1082,7 @@ amdmsCOMPL amdmsSmoothData(amdmsCALIBRATION_SETUP *calib, amdmsDATA *src, amdmsD
   if ((calib->corrFlag & amdmsBAD_PIXEL_CORRECTION) == 0) {
     return amdmsSUCCESS;
   }
-  nPixels = src->nx*src->ny;
+  //nPixels = src->nx*src->ny;
   for (iY = 0; iY < src->ny ; iY++) {
     for (iX = 0; iX < src->nx; iX++) {
       iPixel = src->nx*iY + iX;
