@@ -35,6 +35,8 @@ cpl_error_code amber_CalibVis(const char * recipename, const char * filename,
 	cpl_frame         * science_frame;
 	cpl_propertylist  * plist=NULL;
 	char              * tag_needed=NULL;
+    int                 nframes=0 ;
+    int                 i=0 ;
 
 	/*cpl_frameset_dump(frameset, NULL);
 exit(0);*/
@@ -73,14 +75,16 @@ exit(0);*/
 	}
 	cpl_free(tag_needed);
 
-	science_frame = cpl_frameset_get_first(frameset);
-	while(science_frame)
+	/* Initialize */
+    nframes = cpl_frameset_get_size(frameset) ;
+
+	for (i=0 ; i<nframes ; i++)
 	{
+        science_frame = cpl_frameset_get_position(frameset, i) ;
 		if(!strcmp(cpl_frame_get_filename(science_frame),filename))
 		{
 			break;
 		}
-		science_frame = cpl_frameset_get_next( frameset );
 	}
 	if (science_frame == NULL) {
 		cpl_msg_error(cpl_func, "No science frame found in the SOF");
