@@ -83,18 +83,18 @@ static    amdlibRAW_DATA        rawData; /*  = {NULL}; */
 #endif
 
     amdlibERROR_MSG       errMsg;
-static    amdlibRAW_DATA        rawData = {NULL};
-    amdlibSCIENCE_DATA    sky = {NULL};
-    amdlibSCIENCE_DATA    scienceData = {NULL};
-    amdlibP2VM_MATRIX     p2vm = {NULL};
-    amdlibPHOTOMETRY      photometry = {NULL}, imdPhot = {NULL};
-    amdlibWAVELENGTH      wave = {NULL}, imdWave = {NULL};
-    amdlibPISTON          opd = {NULL}, imdOpd = {NULL};
-    amdlibOI_TARGET       target = {NULL};
-    amdlibOI_ARRAY        array = {NULL};
-    amdlibVIS             vis = {NULL}, imdVis = {NULL};
-    amdlibVIS2            vis2 = {NULL}, imdVis2 = {NULL};
-    amdlibVIS3            vis3 = {NULL}, imdVis3 = {NULL};
+static    amdlibRAW_DATA        rawData ;
+    amdlibSCIENCE_DATA    sky;
+    amdlibSCIENCE_DATA    scienceData ;
+    amdlibP2VM_MATRIX     p2vm;
+    amdlibPHOTOMETRY      photometry, imdPhot;
+    amdlibWAVELENGTH      wave, imdWave;
+    amdlibPISTON          opd, imdOpd;
+    amdlibOI_TARGET       target;
+    amdlibOI_ARRAY        array;
+    amdlibVIS             vis , imdVis ;
+    amdlibVIS2            vis2, imdVis2;
+    amdlibVIS3            vis3, imdVis3;
     amdlibSCIENCE_DATA    *skyPtr;
     amdlibSCIENCE_DATA    *sciencePtr;
     amdlibWAVEDATA        waveData;
@@ -118,10 +118,6 @@ static cpl_image * amber_smooth_image_median(
         int                     size_y);
 
 /* amdlib */
-int amdlibIsJHKMode(amdlibRAW_DATA *data);
-amdlibCOMPL_STAT amdlibExplodeJHKScienceData (amdlibSCIENCE_DATA *srcScienceData, 
-                                              amdlibSCIENCE_DATA *dstScienceData, 
-                                              amdlibERROR_MSG    errMsg);
 cpl_propertylist * BeamPosCreateProductHeader(const char * fctid,
 		char * szRawFile, cpl_frame * pFrameProduct);
 void GetPrefix(int iFrame, char * szPrefix);
@@ -238,15 +234,21 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
             break;
 
 	/* Avoid compiler warnings but do nothing */    
-	case CPL_TYPE_FLAG_ARRAY:
+        case CPL_TYPE_FLAG_ARRAY:
         case CPL_TYPE_INVALID:
-	case CPL_TYPE_UCHAR:
-	case CPL_TYPE_UINT:
-	case CPL_TYPE_ULONG:
-	case CPL_TYPE_POINTER:
-	case CPL_TYPE_FLOAT_COMPLEX:
-	case CPL_TYPE_DOUBLE_COMPLEX:
-	case CPL_TYPE_UNSPECIFIED:
+        case CPL_TYPE_UCHAR:
+        case CPL_TYPE_UINT:
+        case CPL_TYPE_ULONG:
+        case CPL_TYPE_POINTER:
+        case CPL_TYPE_FLOAT_COMPLEX:
+        case CPL_TYPE_DOUBLE_COMPLEX:
+        case CPL_TYPE_UNSPECIFIED:
+        case CPL_TYPE_BITMASK:
+        case CPL_TYPE_COMPLEX:
+        case CPL_TYPE_LONG_LONG:
+        case CPL_TYPE_SHORT:
+        case CPL_TYPE_SIZE:
+        case CPL_TYPE_USHORT:
 	/*case CPL_TYPE_COMPLEX: not anymode in CPL 3.0 */
 	  break;    
         /*default:
@@ -265,7 +267,7 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 
 cpl_propertylist * BeamPosCreateProductHeader( const char * fctid, char * szRawFile, cpl_frame * pFrameProduct )
 {
-  int  iStatus = 0;
+  //int  iStatus = 0;
   char szMessage[1024];
   
   cpl_frameset * frameSetTmp;
@@ -321,7 +323,7 @@ cpl_propertylist * BeamPosCreateProductHeader( const char * fctid, char * szRawF
        /* Error */
        sprintf( szMessage, "Error in setting up the product header." ); 
        cpl_msg_info( fctid, "%s", szMessage ); 
-       iStatus = 16;
+       //iStatus = 16;
      }
 #else 
      if( cpl_dfs_setup_product_header(  pHeader,  
@@ -974,7 +976,7 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
 static int amber_BeamPos_create(cpl_plugin * plugin)
 {
     cpl_recipe * recipe = (cpl_recipe *)plugin ;
-    cpl_parameter * p ;
+    //cpl_parameter * p ;
 
     /* Create the parameters list in the cpl_recipe object */
     recipe->parameters = cpl_parameterlist_new() ; 
