@@ -67,20 +67,20 @@ FILE *                pFITSFile;
 
 
 amdlibERROR_MSG       errMsg;
-static    amdlibDARK_DATA dark = {NULL};
-static    amdlibRAW_DATA        rawData = {NULL};
-amdlibSCIENCE_DATA    sky = {NULL};
-amdlibSCIENCE_DATA    scienceData = {NULL};
-amdlibP2VM_MATRIX     p2vm = {NULL};
-amdlibPHOTOMETRY      photometry = {NULL}, imdPhot = {NULL};
-amdlibWAVELENGTH      wave = {NULL}, imdWave = {NULL};
-amdlibPISTON          opd = {NULL}, imdOpd = {NULL};
-amdlibSPECTRUM       spectrum={NULL};
-amdlibOI_TARGET       target = {NULL};
-amdlibOI_ARRAY        array = {NULL};
-amdlibVIS             vis = {NULL}, imdVis = {NULL};
-amdlibVIS2            vis2 = {NULL}, imdVis2 = {NULL};
-amdlibVIS3            vis3 = {NULL}, imdVis3 = {NULL};
+static    amdlibDARK_DATA dark;
+static    amdlibRAW_DATA        rawData;
+amdlibSCIENCE_DATA    sky;
+amdlibSCIENCE_DATA    scienceData;
+amdlibP2VM_MATRIX     p2vm;
+amdlibPHOTOMETRY      photometry, imdPhot;
+amdlibWAVELENGTH      wave, imdWave;
+amdlibPISTON          opd, imdOpd;
+amdlibSPECTRUM        spectrum;
+amdlibOI_TARGET       target;
+amdlibOI_ARRAY        array;
+amdlibVIS             vis, imdVis;
+amdlibVIS2            vis2, imdVis2;
+amdlibVIS3            vis3, imdVis3;
 amdlibSCIENCE_DATA    *skyPtr;
 amdlibSCIENCE_DATA    *sciencePtr;
 amdlibWAVEDATA        waveData;
@@ -110,8 +110,8 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		const char *inputFile,
 		/*		const char *outputFile,*/
 		const int nbBinning,
-		const amdlibERROR_TYPE errorType,
-		const amdlibPISTON_ALGORITHM pistonType,
+		const amdlibERROR_TYPE errorType_local,
+		const amdlibPISTON_ALGORITHM pistonType_local,
 		const amdlibBOOLEAN noCheckP2vmId,
 		const char * fctid);
 cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile );
@@ -168,7 +168,7 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 		const cpl_propertylist * other)
 {
 
-	int i, c;
+	int i_local, c;
 	char szPAF[2048];
 	char szTMP[2048];
 
@@ -176,10 +176,10 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 
 	/*visir_assure_code(self, CPL_ERROR_NULL_INPUT);*/
 
-	for (i=0; i < cpl_propertylist_get_size(other); i++)
+	for (i_local=0; i_local < cpl_propertylist_get_size(other); i_local++)
 	{
 		const cpl_property * prop = cpl_propertylist_get((cpl_propertylist *)
-				other, i);
+				other, i_local);
 		const char * name    = cpl_property_get_name(prop);
 		/*const char * comment = cpl_property_get_comment(prop);*/
 
@@ -208,6 +208,7 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 		case CPL_TYPE_CHAR:
 			err = cpl_propertylist_append_char(self, name,
 					cpl_property_get_char(prop));
+			break;
 		case CPL_TYPE_BOOL:
 			err = cpl_propertylist_append_bool(self, name,
 					cpl_property_get_bool(prop));
@@ -242,6 +243,12 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 		case CPL_TYPE_POINTER:
 		case CPL_TYPE_FLOAT_COMPLEX:
 		case CPL_TYPE_DOUBLE_COMPLEX:
+		case CPL_TYPE_BITMASK:
+		case CPL_TYPE_COMPLEX:
+		case CPL_TYPE_LONG_LONG:
+		case CPL_TYPE_SHORT:
+		case CPL_TYPE_SIZE:
+		case CPL_TYPE_USHORT:
 		case CPL_TYPE_UNSPECIFIED:
 			/*case CPL_TYPE_COMPLEX: not anymode in CPL 3.0 */
 			break;
@@ -261,12 +268,12 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 
 cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 				{
-	int  iStatus = 0;
+	//int  iStatus = 0;
 	char szMessage[1024];
-	cpl_table        * pTable;
-	cpl_propertylist * pTableHeader;
-	int                iTable;
-	int                iError;
+	//cpl_table        * pTable;
+	//cpl_propertylist * pTableHeader;
+	//int                iTable;
+	//int                iError;
 
 	cpl_frameset * frameSetTmp;
 	cpl_frame    * frameTmp;
@@ -298,7 +305,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 	else
 	{
 		cpl_msg_info( fctid, "No memory for product frame." );
-		iStatus = 15;
+		//iStatus = 15;
 	}
 
 	/*
@@ -367,7 +374,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
 		cpl_msg_info( fctid, "%s", szMessage );
-		iStatus = 16;
+		//iStatus = 16;
 	}
 #else 
 	if( cpl_dfs_setup_product_header(  pHeader,
@@ -397,10 +404,10 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 
 	/* Write the product including proper DFS header*/
 
-	pTable       = NULL;
-	pTableHeader = NULL;
-	iTable = 1;
-	iError = CPL_ERROR_NONE;
+	//pTable       = NULL;
+	//pTableHeader = NULL;
+	//iTable = 1;
+	//iError = CPL_ERROR_NONE;
 
 	sprintf( szMessage, "Creating product file%s...", szFilenameProduct );
 	cpl_msg_info( fctid, "%s", szMessage );
@@ -424,23 +431,23 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		const char *inputFile,
 		/*		const char *outputFile,*/
 		const int nbBinning,
-		const amdlibERROR_TYPE errorType,
-		const amdlibPISTON_ALGORITHM pistonType,
+		const amdlibERROR_TYPE errorType_local,
+		const amdlibPISTON_ALGORITHM pistonType_local,
 		const amdlibBOOLEAN noCheckP2vmId,
 		const char * fctid
 )
 {
 
 
-	char szCommand[1024];
+	//char szCommand[1024];
 	const char * pszARCFILE;
 
 	amdlibCOMPL_STAT Status = amdlibSUCCESS;
 
-	int  i;
+	//int  i_local;
 	char szMessage[1024];
 
-	amdlibCPT_VIS_OPTIONS visOptions = {nbBinning, errorType, pistonType,
+	amdlibCPT_VIS_OPTIONS visOptions = {nbBinning, errorType_local, pistonType_local,
 			noCheckP2vmId, amdlibNO_FRAME_SEL, 1.0};
 
 
@@ -531,7 +538,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		cpl_msg_info( fctid, "%s", szMessage );
 
 		/* Load data file so that the false bias mimics its structure */
-		i=6;
+		//i_local=6;
 		sprintf( szMessage, "Getting PIXEL BIAS MAP from raw %s ...", inputFile );
 		cpl_msg_info( fctid, "%s", szMessage );
 		if (amdlibLoadRawData(inputFile, &rawData, errMsg) != amdlibSUCCESS)
@@ -1551,7 +1558,7 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 	cpl_frame     ** frame_selector_snr=NULL;
 	cpl_frame     ** frame_selector_pst=NULL;
 	cpl_errorstate   prestate=0;
-	int i=0;
+	int i_local=0;
 	int status_snr=0;
 	int status_pst=0;
 	double x1_pst=0.;
@@ -1563,34 +1570,34 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 
 	/*------------------------------------------------------------------------*/
 	/*Run the selector*/
-	for( i=0; i<iProductNumber && i<MAXFILESPRODUCTS; i++ )
+	for( i_local=0; i_local<iProductNumber && i_local<MAXFILESPRODUCTS; i_local++ )
 	{
 		/* Insert this frame, so that caller can rename it to proper DMD product */
 
-		if( pframeSCIENCE[i] )
+		if( pframeSCIENCE[i_local] )
 		{
 			local_framelist=cpl_frameset_new();
-			local_frame=cpl_frame_duplicate(pframeSCIENCE[i]);
+			local_frame=cpl_frame_duplicate(pframeSCIENCE[i_local]);
 			cpl_frame_set_group(local_frame,CPL_FRAME_GROUP_CALIB);
 			cpl_frameset_insert(local_framelist, local_frame);
 
 			/*Get the pst selection values and the isScience value*/
 			get_selection_param(&x1_pst, &x2_pst, &x3_pst, &isScience,
-					pframeSCIENCE[i]);
+					pframeSCIENCE[i_local]);
 
 			/*Select according to SNR*/
 			outname_selector = cpl_sprintf("snr_filtered_%s",
-					cpl_frame_get_filename(pframeSCIENCE[i]));
+					cpl_frame_get_filename(pframeSCIENCE[i_local]));
 			status_snr=amber_selector_lib(50, 50, 50, 1, 0,
 					"Fringe_SNR_percentage_x",
-					cpl_frame_get_filename(pframeSCIENCE[i]),
+					cpl_frame_get_filename(pframeSCIENCE[i_local]),
 					outname_selector, isScience,
 					local_framelist, parlist, "amber_SciCal");
 			if(status_snr==0)
 			{
-				frame_selector_snr[i]=cpl_frame_duplicate(
+				frame_selector_snr[i_local]=cpl_frame_duplicate(
 						cpl_frameset_get_position(local_framelist,1));
-				cpl_frameset_insert(framelist,frame_selector_snr[i]);
+				cpl_frameset_insert(framelist,frame_selector_snr[i_local]);
 				cpl_frameset_erase_frame(local_framelist,
 						cpl_frameset_get_position(local_framelist,1));
 
@@ -1637,17 +1644,17 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 			/*Select according to PISTON*/
 
 			outname_selector = cpl_sprintf("pst_filtered_%s",
-					cpl_frame_get_filename(pframeSCIENCE[i]));
+					cpl_frame_get_filename(pframeSCIENCE[i_local]));
 			status_pst=amber_selector_lib(x1_pst, x2_pst, x3_pst, 1, 0,
 					"Absolute_piston_value_lt_x",
-					cpl_frame_get_filename(pframeSCIENCE[i]),
+					cpl_frame_get_filename(pframeSCIENCE[i_local]),
 					outname_selector, isScience,
 					local_framelist, parlist, "amber_SciCal");
 			if(status_pst==0)
 			{
-				frame_selector_pst[i]=cpl_frame_duplicate(
+				frame_selector_pst[i_local]=cpl_frame_duplicate(
 						cpl_frameset_get_position(local_framelist,1));
-				cpl_frameset_insert(framelist,frame_selector_pst[i]);
+				cpl_frameset_insert(framelist,frame_selector_pst[i_local]);
 				cpl_frameset_erase_frame(local_framelist,
 						cpl_frameset_get_position(local_framelist,1));
 
