@@ -213,7 +213,7 @@ static int amber_raw_to_fitsimage(
 	strcpy( szProduct, "/tmp/amber_display.fits" );
 
 	/* Just use the first frame */
-	cur_frame = cpl_frameset_get_first( frameset );
+	cur_frame = cpl_frameset_get_position(frameset, 0);
 	cpl_frame_set_group(cur_frame, CPL_FRAME_GROUP_RAW);
 	pszInfile = (char *)cpl_frame_get_filename( cur_frame );
 
